@@ -1,15 +1,17 @@
 from cyberpunk_theme.widget import label
 from cyberpunk_theme.widget import toplevel
 from cyberpunk_theme import constant
-import tkstyle
 
 
 # == toast theme
-def get_style():
+def get_style(font_family=constant.FONT_FAMILY,
+              font_size=constant.FONT_SIZE):
     style = toplevel.get_style()
-    style.background = constant.COLOR_BLACK
-    #style.add(_get_toast_header_label_style(), pattern="*label_header")
-    #style.add(_get_toast_message_label_style(), pattern="*label_message")
+    style.background = constant.BACKGROUND_COLOR
+    style.add(_get_toast_header_label_style(font_family=font_family,
+                                            font_size=font_size),
+              pattern="*label_header")
+    style.add(_get_toast_message_label_style(), pattern="*label_message")
     return style
 
 
@@ -18,9 +20,10 @@ def get_style():
 # ========================================
 
 # toast header
-def _get_toast_header_label_style():
+def _get_toast_header_label_style(font_family=constant.FONT_FAMILY,
+                                  font_size=constant.FONT_SIZE):
     style = label.get_style()
-    style.font = constant.FONT_FAV_BOLD
+    style.font = (font_family, font_size, "bold")
     style.background = "#101818"
     style.foreground = "#B4C7EF"
     return style
